# Pytdl Python的YTDL!

***

目前簡化為四種功能~~

| 方法 | 傳回參數 |
| :-----: | :-----: |
| `songList(query : str, size : int = 12)` | List[dict] |
| `searchList(list_id : str)` | List[dict] |
| `songs(querys : List[str])` | List[songList] |
| `info(url : str)` | Song or SongList |

songList 回傳的結構為
```py
[{
	"id": str,
	"title": str,
	"thumbnail": list,
	"length": str
}, ...]
```

searchList 回傳的結構如同 songList 的結構

songs 回傳的結構為
```py
[songList(), ...]
```

info 回傳的結構為
```py
[Song() | SongList(), ...]
```

Song 與 SongList 要使用 create 創建其結構 (async func)

SongList 創建後的 SongList.songs 為一個 list

如果 Song 傳入的是網址的列表，那他會有一個 Song.Songs 的屬性，是 Song 的 list

```py
from NPytdl import Pytdl
ydl = Pytdl()

song = ydl.info("https://youtu.be/RGtSdbjxVKU")

import asyncio
asyncio.run(song.create())

song.download(f"./test/{song.title}")
```

download 是 `download(path : str, stype : str = "audio")` 要下載影片就將 stype 換成 video

這樣就能下載這首歌
